import 'bootstrap.css';
import '@grapecity/wijmo.styles/wijmo.css';
import './styles.css';
//
import { Component, enableProdMode, NgModule, ViewChild } from '@angular/core';
import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
import { BrowserModule } from '@angular/platform-browser';
import * as wjcCore from '@grapecity/wijmo';
import * as wjcGrid from '@grapecity/wijmo.grid';
import { WjGridModule } from '@grapecity/wijmo.angular2.grid';
import { FormsModule } from '@angular/forms';
//
@Component({
    selector: 'app-component',
    templateUrl: 'src/app.component.html'
})
export class AppComponent
{
    data: any[];
    currentCellValue: any;
    cellColIndex: number;
    cellRowIndex: number;
    totalRows: number;
    totalColumns: number;
    result: any;
    // references FlexGrid named 'flex' in the view
    @ViewChild('flex', { static: true }) flex: wjcGrid.FlexGrid;

    // DataSvc will be passed by derived classes
    constructor()
    {
        this.data = this._getData();
        this.cellColIndex = 0;
        this.cellRowIndex = 0;
        this.result = "...";
    }

    flexInitialized(flexgrid: wjcGrid.FlexGrid)
    {

        this.totalRows = flexgrid.rows.length - 1;
        this.totalColumns = flexgrid.columns.length - 1;
        console.log(this.totalColumns, this.totalRows);
        this.currentCellValue = flexgrid.getCellData(this.cellRowIndex, this.cellColIndex, false);

        //To add event listener to the element.
        flexgrid.prepareCellForEdit.addHandler((sender, args) => {
            if (args.col === this.cellColIndex && args.row === this.cellRowIndex && flexgrid.activeEditor !== null)
            {
                flexgrid.activeCell.addEventListener('input', (e) =>
                {
                    this.currentCellValue = flexgrid.activeEditor.value;
                })
            }
        })

        //To update the colIndex and rowIndex as the selection changes.
        flexgrid.selectionChanged.addHandler((sender, args) =>
        {
            this.cellColIndex = args.col;
            this.cellRowIndex = args.row;
            this.currentCellValue = sender.getCellData(args.row, args.col, false);
        })
    }

    //To update the cell data as the value of input field changes.
    updateCell()
    {
        this.result = this.flex.setCellData(this.cellRowIndex, this.cellColIndex, this.currentCellValue, true, true);
    }

    private _getData()
    {
        // create some random data
        let countries = 'US,Germany,UK,Japan,Italy,Greece'.split(','),
            data = [];
        for (let i = 0; i < countries.length; i++)
        {
            data.push({
                id: i,
                country: countries[i],
                sales: Math.random() * 10000,
                expenses: Math.random() * 5000
            });
        }

        return data;
    }
}
//
@NgModule({
    imports: [WjGridModule, BrowserModule, FormsModule],
    declarations: [AppComponent],
    bootstrap: [AppComponent]
})
export class AppModule
{
}
//
enableProdMode();
// Bootstrap application with hash style navigation and global services.
platformBrowserDynamic().bootstrapModule(AppModule);

